==> bonita-common-6.3.1-sources.jar: org/bonitasoft/engine/bpm/document/ArchivedDocumentsSearchDescriptor.java <==
/**
 * Copyright (C) 2012 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.bpm.document;

/**
 * @author Zhang Bole
 */
public final class ArchivedDocumentsSearchDescriptor {

    public static final String PROCESSINSTANCE_ID = "processinstanceid";
    
    public static final String SOURCEOBJECT_ID = "sourceObjectId";
    
    public static final String ARCHIVE_DATE = "archiveDate";
    
    public static final String DOCUMENT_NAME = "documentName";

    public static final String DOCUMENT_AUTHOR = "documentAuthor";

    public static final String DOCUMENT_CREATIONDATE = "documentCreationDate";

    public static final String DOCUMENT_HAS_CONTENT = "documentHasContent";

    public static final String DOCUMENT_CONTENT_FILENAME = "documentContentFileName";

    public static final String DOCUMENT_CONTENT_MIMETYPE = "documentContentMimeType";

    public static final String CONTENT_STORAGE_ID = "contentStorageId";

    public static final String DOCUMENT_URL = "documentURL";

}

==> bonita-common-6.5.2-sources.jar: org/bonitasoft/engine/bpm/document/ArchivedDocumentsSearchDescriptor.java <==
/**
 * Copyright (C) 2012 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.bpm.document;

/**
 * @author Zhang Bole
 */
public final class ArchivedDocumentsSearchDescriptor {

    public static final String PROCESSINSTANCE_ID = "processinstanceid";
    
    public static final String SOURCEOBJECT_ID = "sourceObjectId";
    
    public static final String ARCHIVE_DATE = "archiveDate";
    
    public static final String DOCUMENT_NAME = "documentName";

    public static final String DOCUMENT_DESCRIPTION  = "documentDescription";

    public static final String DOCUMENT_VERSION = "version";

    public static final String DOCUMENT_AUTHOR = "documentAuthor";

    public static final String DOCUMENT_CREATIONDATE = "documentCreationDate";

    public static final String DOCUMENT_HAS_CONTENT = "documentHasContent";

    public static final String DOCUMENT_CONTENT_FILENAME = "documentContentFileName";

    public static final String DOCUMENT_CONTENT_MIMETYPE = "documentContentMimeType";

    public static final String CONTENT_STORAGE_ID = "contentStorageId";

    public static final String DOCUMENT_URL = "documentURL";

    public static final String LIST_INDEX = "index";

}
